@@ -159,24 +159,35 @@ function help => sub {
 	}
 };
 
-
 function read => sub {
 	my ($self, $file, $unprotected) = @_;
 	$self->unprotected_read = $unprotected if $unprotected;
 	$self->salus->file = $file;
-	$self->salus->read();
+	eval { $self->salus->read(); };
+	$self->say($@ ? $@ : "read file");
+	$self->unprotected_read = 0;
+};
+
+function combine => sub {
+	my ($self, $file, $unprotected) = @_;
+	$self->unprotected_read = $unprotected if $unprotected;
+	$self->salus->file = $file;
+	eval { $self->salus->combine() };
+	$self->say($@ ? $@ : "combined file");
 	$self->unprotected_read = 0;
 };
 
 function write => sub {
 	my ($self, $file) = @_;
 	$self->salus->file = $file if $file;
-	$self->salus->write();
+	eval { $self->salus->write(); };
+	$self->say($@ ? $@ : "wrote file");	
 };
 
 function add => sub {
 	my ($self, @row) = @_;
-	$self->salus->add_row(\@row);
+	eval { $self->salus->add_row(\@row); };
+	$self->say($@ ? $@ : "created row");	
 };
 
 function all => sub {
@@ -191,9 +202,9 @@ function all => sub {
 
 function get => sub {
 	my ($self, $index) = @_;
-	my $row = $self->salus->get_row($index);
+	my $row = eval { $self->salus->get_row($index) };
 	unless ($row) {
-		$self->say("No row available for index ${index}");
+		$self->say($@ ? $@ : "no row available for index ${index}");
 	 	return;
 	}
 	$self->print_table($row->as_array);
@@ -201,27 +212,36 @@ function get => sub {
 
 function get_col => sub {
 	my ($self, $r, $c) = @_;
-	$self->salus->set_row_col($r, $c);
+	my $col = eval { $self->salus->get_row_col($r, $c) };
+	unless ($col) {
+		$self->say($@ ? $@ : "no column available for index ${r} ${c}");
+	 	return;
+	}
+	$self->say(($col->header->label || $col->header->name) . " value " . $col->value);
 };
 
 function set => sub {
 	my ($self, $r, @row) = @_;
-	$self->salus->set_row($r, \@row);
+	eval { $self->salus->set_row($r, \@row) };
+	$self->say($@ ? $@ : "set row");	
 };
 
 function set_col => sub {
 	my ($self, $r, $c, $v) = @_;
-	$self->salus->set_row_col($r, $c, $v);
+	eval { $self->salus->set_row_col($r, $c, $v) };
+	$self->say($@ ? $@ : "set column");	
 };
 
 function delete => sub {
 	my ($self, $row) = @_;
-	$self->salus->delete_row($row);
+	eval { $self->salus->delete_row($row) };
+	$self->say($@ ? $@ : "deleted row");	
 };
 
 function delete_col => sub {
 	my ($self, $r, $c) = @_;
-	$self->salus->delete_row_col($r, $c);
+	eval { $self->salus->delete_row_col($r, $c) };
+	$self->say($@ ? $@ : "deleted column");	
 };
 
 function extract_line_args => sub {
@@ -245,12 +265,13 @@ function headers => sub {
 
 function sort => sub {
 	my ($self, $col, $order) = @_;
-	$self->salus->sort($col, $order);
+	eval { $self->salus->sort($col, $order); };
+	$self->say($@ ? $@ : "sorted rows");
 };
 
 function search => sub {
 	my ($self, $col, $search, $include_index) = @_;
-	my ($rows, $indexes) = $self->salus->search($col, $search);
+	my ($rows, $indexes) = eval { $self->salus->search($col, $search) };
 	my @rows;
 	for (my $i = 0; $i < @{$rows}; $i++) {
 		my $row = $rows->[$i]->as_array();
@@ -261,7 +282,7 @@ function search => sub {
 
 function find => sub {
 	my ($self, $col, $search) = @_;
-	my $index = $self->salus->find($col, $search);
+	my $index = eval { $self->salus->find($col, $search) };
 	$self->say(defined $index 
 		? qq|Found row matching search query (${search}) with index: ${index}|
 		: qq|Cannot find row matching search (${search})|
